@@ -1,12 +1,42 @@
 from enum import Enum
+from typing import Any
+
+
+class Metadata:
+    trace_id: str
+    user_id: str
+
+    def __init__(self, trace_id: str, user_id: str) -> None:
+        self.trace_id = trace_id
+        self.user_id = user_id
+
+
+class Subjects(Enum):
+    ADD_USER = "AddUser"
+    MODIFY_USER = "ModifyUser"
+    USER_ADDED = "UserAdded"
+    USER_MODIFIED = "UserModified"
+
+
+class Message:
+    data: Any
+    id: str
+    metadata: Metadata
+    subject: Subjects
+
+    def __init__(self, data: Any, id: str, metadata: Metadata, subject: Subjects) -> None:
+        self.data = data
+        self.id = id
+        self.metadata = metadata
+        self.subject = subject
 
 
 class Commands(Enum):
+    ADD_USER = "AddUser"
     MODIFY_USER = "ModifyUser"
-    REGISTER_USER = "RegisterUser"
 
 
-class RegisterUserCommandData:
+class AddUserCommandData:
     auth0_id: str
     email: str
     email_verified: bool
@@ -27,30 +57,21 @@ class RegisterUserCommandData:
         self.picture = picture
 
 
-class Metadata:
-    trace_id: str
-    user_id: str
-
-    def __init__(self, trace_id: str, user_id: str) -> None:
-        self.trace_id = trace_id
-        self.user_id = user_id
+class AddUserCommandSubject(Enum):
+    ADD_USER = "AddUser"
 
 
-class RegisterUserCommandType(Enum):
-    REGISTER_USER = "RegisterUser"
-
-
-class RegisterUserCommand:
-    data: RegisterUserCommandData
+class AddUserCommand:
+    data: AddUserCommandData
     id: str
     metadata: Metadata
-    type: RegisterUserCommandType
+    subject: AddUserCommandSubject
 
-    def __init__(self, data: RegisterUserCommandData, id: str, metadata: Metadata, type: RegisterUserCommandType) -> None:
+    def __init__(self, data: AddUserCommandData, id: str, metadata: Metadata, subject: AddUserCommandSubject) -> None:
         self.data = data
         self.id = id
         self.metadata = metadata
-        self.type = type
+        self.subject = subject
 
 
 class ModifyUserCommandData:
@@ -66,7 +87,7 @@ class ModifyUserCommandData:
         self.picture = picture
 
 
-class ModifyUserCommandType(Enum):
+class ModifyUserCommandSubject(Enum):
     MODIFY_USER = "ModifyUser"
 
 
@@ -74,21 +95,21 @@ class ModifyUserCommand:
     data: ModifyUserCommandData
     id: str
     metadata: Metadata
-    type: ModifyUserCommandType
+    subject: ModifyUserCommandSubject
 
-    def __init__(self, data: ModifyUserCommandData, id: str, metadata: Metadata, type: ModifyUserCommandType) -> None:
+    def __init__(self, data: ModifyUserCommandData, id: str, metadata: Metadata, subject: ModifyUserCommandSubject) -> None:
         self.data = data
         self.id = id
         self.metadata = metadata
-        self.type = type
+        self.subject = subject
 
 
 class Events(Enum):
+    USER_ADDED = "UserAdded"
     USER_MODIFIED = "UserModified"
-    USER_REGISTERED = "UserRegistered"
 
 
-class UserRegisteredEventData:
+class UserAddedEventData:
     auth0_id: str
     email: str
     email_verified: bool
@@ -109,21 +130,21 @@ class UserRegisteredEventData:
         self.picture = picture
 
 
-class UserRegisteredEventType(Enum):
-    USER_REGISTERED = "UserRegistered"
+class UserAddedEventSubject(Enum):
+    USER_ADDED = "UserAdded"
 
 
-class UserRegisteredEvent:
-    data: UserRegisteredEventData
+class UserAddedEvent:
+    data: UserAddedEventData
     id: str
     metadata: Metadata
-    type: UserRegisteredEventType
+    subject: UserAddedEventSubject
 
-    def __init__(self, data: UserRegisteredEventData, id: str, metadata: Metadata, type: UserRegisteredEventType) -> None:
+    def __init__(self, data: UserAddedEventData, id: str, metadata: Metadata, subject: UserAddedEventSubject) -> None:
         self.data = data
         self.id = id
         self.metadata = metadata
-        self.type = type
+        self.subject = subject
 
 
 class UserModifiedEventData:
@@ -139,7 +160,7 @@ class UserModifiedEventData:
         self.picture = picture
 
 
-class UserModifiedEventType(Enum):
+class UserModifiedEventSubject(Enum):
     USER_MODIFIED = "UserModified"
 
 
@@ -147,10 +168,10 @@ class UserModifiedEvent:
     data: UserModifiedEventData
     id: str
     metadata: Metadata
-    type: UserModifiedEventType
+    subject: UserModifiedEventSubject
 
-    def __init__(self, data: UserModifiedEventData, id: str, metadata: Metadata, type: UserModifiedEventType) -> None:
+    def __init__(self, data: UserModifiedEventData, id: str, metadata: Metadata, subject: UserModifiedEventSubject) -> None:
         self.data = data
         self.id = id
         self.metadata = metadata
-        self.type = type
+        self.subject = subject
